@@ -1,5 +1,8 @@
+import os
 import click
 
+from rich.console import Console
+
 try:
     from uptodate.core import UpToDate
 except Exception:
@@ -8,6 +11,8 @@ except Exception:
 
 DEFAULT_FILE_PATH = 'requirements.txt'
 
+console = Console()
+
 
 @click.command()
 @click.argument('file_paths', nargs=-1, type=click.Path(exists=True))
@@ -15,11 +20,13 @@ def up_to_date(file_paths):
     """Scan requirements.txt file for dependences which are not up to date"""
 
     if len(file_paths) == 0:
-        file_paths = (DEFAULT_FILE_PATH,)
+        if os.path.isfile(DEFAULT_FILE_PATH):
+            file_paths = (DEFAULT_FILE_PATH,)
+        else:
+            console.print('No requirements file found', style='yellow')
 
+    uptodate = UpToDate(console)
     for file_path in file_paths:
-        click.secho(file_path, fg='blue')
-        uptodate = UpToDate()
         uptodate.check(file_path)
 
 
