@@ -1,22 +1,19 @@
 import pytest
 
+from rich.console import Console
 from unittest.mock import patch, mock_open
-
 from uptodate.core import RequirementsScanner
 
 
 @pytest.fixture
 def scanner():
-    return RequirementsScanner()
+    console = Console()
+    return RequirementsScanner(console)
 
 
 @pytest.fixture
 def open_mock():
-    read_data = '\n'.join([
-        'click==6.7',
-        'pytest==3.2.5',
-        'celery[redis]==4.0.2'
-    ])
+    read_data = '\n'.join(['click==6.7', 'pytest==3.2.5', 'celery[redis]==4.0.2'])
 
     return mock_open(read_data=read_data)
 
