@@ -1,11 +1,13 @@
 import pytest
 
+from rich.console import Console
 from uptodate.core import UpToDate, Row
 
 
 @pytest.fixture
 def uptodate():
-    return UpToDate()
+    console = Console()
+    return UpToDate(console)
 
 
 @pytest.fixture
@@ -20,9 +22,7 @@ def latest_versions():
 
 @pytest.fixture
 def rows():
-    return [
-        Row(name='pytest', current_version='3.0.0', latest_version='3.2.5')
-    ]
+    return [Row(name='pytest', current_version='3.0.0', latest_version='3.2.5')]
 
 
 def test_prepare_rows(uptodate, dependences, latest_versions, rows):
